/*
 * file CcProviderMangerCallback.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM
 * 
 * com.ibm.rational.wvcm.stp.cc.CcProvider
 *
 * (C) Copyright IBM Corporation 2009, 2011.  All Rights Reserved. 
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or  
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
 */
package com.ibm.rational.wvcm.stp.cc;

import com.ibm.rational.wvcm.stp.cq.CqProvider;

/**
 * Callback invoked by CcProvider.getClientViewList(), etc. that allows caller
 * to specify the provider to be used for creating view proxies.
 * @see CcProvider#getClientViewList(javax.wvcm.PropertyRequestItem.PropertyRequest)
 * @see CcProvider#registerProviderManagerCallback(com.ibm.rational.wvcm.stp.cc.CcProviderManagerCallback)
 */
public interface CcProviderManagerCallback {

    /**
     * Specify the local provider (LOCAL_PROVIDER_CLASS) to use to create
     * a dynamic view proxy.
     * @return local provider; if null, corresponding view proxy will be
     *         omitted from the list.
     */
    CcProvider getLocalProvider();

    /**
     * Specify the network provider (NETWORK_PROVIDER_CLASS) to use to create
     * a web view proxy.
     * @param serverUrl web view's server URL.  Typically the caller keeps
     *        a map of server URLs to network providers, and returns the
     *        provider matching this URL.
     * @return network provider for specified server URL;
     *         if null, corresponding view proxy will be omitted from the list.
     */
    CcProvider getNetworkProvider(String serverUrl);

    /**
     * Specify the ClearQuest provider to use to create ClearQuest resource
     * proxies and perform ClearQuest operations.
     * @param serverUrl ClearQuest Web server URL.  Typically the caller keeps
     *        a map of server URLs to providers, and returns the
     *        provider matching this URL.
     * @return ClearQuest provider, or null if caller is unable to provide one
     */
    CqProvider getClearQuestProvider(String serverUrl);
}
